Operational types that allow the use of the monoid operation as an operator.
Structs
- Additive
- Write a monoid additively.
- Multiplicative
- Write a monoid multiplicatively.
Operational types that allow the use of the monoid operation as an operator.